Projectors
==========

.. automodule:: mumott.methods.projectors

.. index::
   single: Class reference; SAXSProjectorCUDA
.. autoclass:: mumott.methods.projectors.SAXSProjectorCUDA
   :members:
   :undoc-members:
   :inherited-members:

.. index::
   single: Class reference; SAXSProjectorAstra
.. autoclass:: mumott.methods.projectors.SAXSProjectorAstra
   :members:
   :undoc-members:
   :inherited-members:

.. index::
   single: Class reference; SAXSProjectorNumba
.. autoclass:: mumott.methods.projectors.SAXSProjectorNumba
   :members:
   :undoc-members:
   :inherited-members:

